<?php
include_once '../includes/db_connection.php';
include_once '../includes/session_management.php';
include_once '../includes/sanitize.php';

// Admin kontrolü
if (!isAdmin()) {
    header('Location: ../public/login.php');
    exit;
}

// Kullanıcıyı Getir
if (isset($_POST['user_id'])) {
    $user_id = sanitizeInput($_POST['user_id']);
    $conn = getDbConnection();
    $sql = "SELECT username, email, balance FROM users WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($username, $email, $balance);
    $stmt->fetch();
    $stmt->close();
    $conn->close();
} else {
    echo "<p>Hata: Kullanıcı bulunamadı.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Kullanıcı Düzenleme</title>
    <link rel="stylesheet" href="../styles/styles.css">
</head>
<body>
    <h2>Kullanıcıyı Düzenle</h2>
    <form method="POST" action="user_management.php?action=edit_user">
        <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($user_id); ?>">
        <label for="username">Kullanıcı Adı:</label>
        <input type="text" id="username" name="username" value="<?php echo htmlspecialchars($username); ?>" required><br>
        <label for="email">Email:</label>
        <input type="email" id="email" name="email" value="<?php echo htmlspecialchars($email); ?>" required><br>
        <label for="balance">Bakiye (TL):</label>
        <input type="number" id="balance" name="balance" value="<?php echo htmlspecialchars($balance); ?>" step="0.01" required><br>
        <button type="submit">Kaydet</button>
    </form>
</body>
</html>
