<?php
include_once '../includes/db_connection.php';
include_once '../includes/session_management.php';
include_once '../includes/sanitize.php';

if (!isLoggedIn()) {
    echo json_encode(["status" => "error", "message" => "Lütfen giriş yapın."], JSON_UNESCAPED_UNICODE);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_GET['action']) && $_GET['action'] == 'add_to_cart') {
    $user_id = $_SESSION['user_id'];
    $product_id = sanitizeInput($_POST['product_id']);
    $quantity = isset($_POST['quantity']) ? (int)sanitizeInput($_POST['quantity']) : 1;

    $conn = getDbConnection();
    $sql = "SELECT * FROM cart WHERE user_id = ? AND product_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ii", $user_id, $product_id);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $update_sql = "UPDATE cart SET quantity = quantity + ? WHERE user_id = ? AND product_id = ?";
        $stmt_update = $conn->prepare($update_sql);
        $stmt_update->bind_param("iii", $quantity, $user_id, $product_id);
        $stmt_update->execute();
        $stmt_update->close();
    } else {
        $insert_sql = "INSERT INTO cart (user_id, product_id, quantity) VALUES (?, ?, ?)";
        $stmt_insert = $conn->prepare($insert_sql);
        $stmt_insert->bind_param("iii", $user_id, $product_id, $quantity);
        $stmt_insert->execute();
        $stmt_insert->close();
    }

    echo json_encode(["status" => "success", "message" => "Ürün sepete eklendi."], JSON_UNESCAPED_UNICODE);

    $stmt->close();
    $conn->close();
}
?>
